Learn R Programming

TraMineRextras (version 0.4.0)

seqrep.grp: Finding representative sets by group and their quality statistics.

Description

This function determines representative sequences by group and returns the representatives by group and/or the quality statistics of the representative sets. The function is a wrapper for the TraMineR seqrep function.

Usage

seqrep.grp(seqdata, group = NULL, diss = NULL, ret="stat", mdis=diss,...)

Arguments

seqdata

state sequence object as defined by seqdef.

group

group variable. If NULL a single group is assumed.

diss

dissimilarity matrix. If NULL the "LCS" dissimilarity matrix is computed.

ret

What should be returned? One of "stat" (default), "rep" or "both".

mdis

Deprecated, use "diss" instead.

...

additional arguments passed to seqrep .

Value

If ret="stat", a list with the quality statistics for the set of representatives of each group.

If ret="rep", a list with the set of representatives of each group.

If ret="both", a list with the two previous outcomes.

Details

The function is a wrapper for running seqrep on the different groups defined by the group variable.

See Also

seqrep

Examples

Run this code
# NOT RUN {
data(biofam)
biofam <- biofam[1:100,]
biofam.lab <- c("Parent", "Left", "Married", "Left+Marr",
"Child", "Left+Child", "Left+Marr+Child", "Divorced")
biofam.short <- c("P","L","M","LM","C","LC","LMC","D")
biofam.seq <- seqdef(biofam[,10:25], alphabet=0:7, states=biofam.short, labels=biofam.lab)
dist <- seqdist(biofam.seq, method="HAM")

seqrep.grp(biofam.seq, group=biofam$plingu02, diss=dist, coverage=.2, pradius=.1)
seqrep.grp(biofam.seq, group=biofam$plingu02, diss=dist, ret="rep", coverage=.2, tsim=.1)
# }

Run the code above in your browser using DataLab